@@ -2005,9 +2005,8 @@ g_option_group_set_parse_hooks (GOptionGroup     *group,
  * Associates a function with @group which will be called 
  * from g_option_context_parse() when an error occurs.
  *
- * Note that the user data to be passed to @pre_parse_func and
- * @post_parse_func can be specified when constructing the group
- * with g_option_group_new().
+ * Note that the user data to be passed to @error_func can be
+ * specified when constructing the group with g_option_group_new().
  *
  * Since: 2.6
  **/
@@ -2054,7 +2053,7 @@ g_option_group_set_translate_func (GOptionGroup   *group,
   group->translate_notify = destroy_notify;
 }
 
-static gchar *
+static const gchar *
 dgettext_swapped (const gchar *msgid, 
 		  const gchar *domainname)
 {
